### Utilities for python(from qiuzhanghua)

#### functions

- find_hf_home_dir()
- find_hf_hub_dir()
- find_hf_datasets_dir()
- find_xdg_cache_home()
- find_model_dir(model: str)
- find_datasets_dir(datasets: str)
